@@ -133,6 +133,10 @@
 /* default="/var/lib/samhain"                 */
 #undef DEFAULT_DATAROOT
 
+/* The quarantine directory.                  */
+/* default="/var/lib/samhain/.quarantine      */
+#undef DEFAULT_QDIR
+
 /* The location of the log file.              */
 /* default="/var/log/samhain_log"             */
 #undef DEFAULT_ERRFILE
@@ -294,6 +298,12 @@
 #undef HOST_IS_LINUX
 #undef HOST_IS_I86LINUX
 
+/* obvious                                    */
+#undef HOST_IS_CYGWIN
+
+/* obvious                                    */
+#undef HOST_IS_DARWIN
+
 /* obvious                                    */
 #undef HOST_IS_FREEBSD
 
